#
# spec file for package hamlib
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   2
Name:           hamlib
Version:        3.3
Release:        bp153.1.20
Summary:        Run-time library to control radio transcievers and receivers
License:        LGPL-2.1-only
Group:          Productivity/Hamradio/Other
URL:            http://hamlib.sourceforge.net
#Git-Clone:     https://git.code.sf.net/p/hamlib/code
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE hamlib-3.0-perl_install.patch -- patch from Fedora
Patch0:         hamlib-3.0-perl_install.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  swig
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(tcl)
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1500
BuildRequires:  pkgconfig(python2)
%else
BuildRequires:  pkgconfig(python3)
%endif
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
The Ham Radio Control Libraries (Hamlib) provide a programming
interface for controlling radios and other shack hardware.
It is a software layer, not a complete user application.

%package devel
Summary:        Development files for hamlib, a set of radio control libraries
Group:          Development/Libraries/Other
Requires:       libhamlib%{sover} = %{version}
Requires:       libhamlib++%{sover} = %{version}

%description devel
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n libhamlib++%{sover}
Summary:        C++ interface of the Ham Radio Control Libraries
Group:          System/Libraries

%description -n libhamlib++%{sover}
Hamlib provides a programming interface for controlling radios and
other shack hardware. It is a software layer, not a complete user
application.

%package -n libhamlib%{sover}
Summary:        C interface of the Ham Radio Control Libraries
Group:          System/Libraries

%description -n libhamlib%{sover}
Hamlib provides a programming interface for controlling radios and
other shack hardware. It is a software layer, not a complete user
application.

%package -n lua-Hamliblua
Summary:        LUA bindings for Hamlib
Group:          Development/Libraries/Other

%description -n lua-Hamliblua
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%if 0%{?suse_version} <= 1500
%package -n python-Hamlib
Summary:        Python bindings for Hamlib
Group:          Development/Libraries/Python

%description -n python-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.
%else
%package -n python3-Hamlib
Summary:        Python 3 bindings for Hamlib
Group:          Development/Libraries/Python

%description -n python3-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.
%endif

%package -n tcl-Hamlib
Summary:        Tcl bindings for Hamlib
Group:          Development/Languages/Tcl
%requires_eq    tcl

%description -n tcl-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%package -n perl-Hamlib
Summary:        Perl bindings for Hamlib
Group:          Development/Languages/Perl

%description -n perl-Hamlib
Hamlib provide a programming interface for controlling radios and
other shack hardware.

%prep
%setup -q
%patch0 -p1

%build
autoreconf -fiv
%configure \
  --with-perl-binding \
  --with-tcl-binding \
  --with-lua-binding \
%if 0%{?suse_version} <= 1500
  --with-python-binding \
%else
  --with-python-binding PYTHON_VERSION='3.8' \
%endif
  --with-xml-support
%make_build

%install
%make_install
find %{buildroot} -type f \( -name '*.a' -o -name '*.la' \) -delete -print

rm %{buildroot}%{perl_vendorarch}/auto/Hamlib/.packlist

mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}/%{_datadir}/doc/%{name} %{buildroot}%{_docdir}

%if 0%{?suse_version} <= 1500
%fdupes %{buildroot}%{python_sitearch}
%endif

%check
%make_build check

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%post -n libhamlib++%{sover} -p /sbin/ldconfig
%post -n libhamlib%{sover} -p /sbin/ldconfig
%postun -n libhamlib++%{sover} -p /sbin/ldconfig
%postun -n libhamlib%{sover} -p /sbin/ldconfig

%files
%license LICENSE
%doc AUTHORS NEWS
%{_bindir}/rigctl
%{_bindir}/rigctld
%{_bindir}/rigmem
%{_bindir}/rigsmtr
%{_bindir}/rigswr
%{_bindir}/rotctl
%{_bindir}/rotctld
%{_mandir}/man1/rigctl.1%{?ext_man}
%{_mandir}/man1/rigctld.1%{?ext_man}
%{_mandir}/man1/rigmem.1%{?ext_man}
%{_mandir}/man1/rigsmtr.1%{?ext_man}
%{_mandir}/man1/rigswr.1%{?ext_man}
%{_mandir}/man1/rotctl.1%{?ext_man}
%{_mandir}/man1/rotctld.1%{?ext_man}
%{_mandir}/man7/hamlib-primer.7%{?ext_man}
%{_mandir}/man7/hamlib-utilities.7%{?ext_man}
%{_mandir}/man7/hamlib.7%{?ext_man}
%{_infodir}/hamlib.info%{?ext_info}
%{_docdir}/hamlib

%files devel
%dir %{_includedir}/hamlib
%{_includedir}/hamlib/*.h
%{_datadir}/aclocal/hamlib.m4
%{_libdir}/pkgconfig/hamlib.pc
%{_libdir}/libhamlib.so
%{_libdir}/libhamlib++.so

%files -n libhamlib%{sover}
%license COPYING COPYING.LIB
%{_libdir}/libhamlib.so.%{sover}*

%files -n libhamlib++%{sover}
%license COPYING COPYING.LIB
%{_libdir}/libhamlib++.so.%{sover}*

%files -n lua-Hamliblua
%{_libdir}/lua

%if 0%{?suse_version} <= 1500
%files -n python-Hamlib
%{python_sitearch}/Hamlib.*
%{python_sitearch}/_Hamlib.*
%else
%files -n python3-Hamlib
%{python3_sitearch}/Hamlib.*
%{python3_sitearch}/_Hamlib.*
%{python3_sitearch}/__pycache__/Hamlib.cpython*.pyc
%endif

%files -n tcl-Hamlib
%dir %{_libdir}/tcl*/
%dir %{_libdir}/tcl*/Hamlib
%{_libdir}/tcl*/Hamlib/*

%files -n perl-Hamlib
%{perl_vendorarch}/*

%changelog
* Wed Apr 29 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Tumbleweed: Python backend built for python-3.8
* Sat Apr 25 2020 Martin Pluskal <mpluskal@suse.com>
- Do not build python2 bindings for Tumbleweed
- Modernise spec file
* Thu Aug 30 2018 mardnh@gmx.de
- Update to version 3.3
  * New models, R&S xk2100, TRXMAnager, Meade LX200
  * HTML manual is now generated at 'make dist' so users don't
    need GNU Info tools installed.  TNX Greg, N1DAM for the suggestion.
  * Handle longer udev generated file names up to 512 characters
  * Add debug time stamps with new '-Z' option and '--debug-time-stamps'
    options to rigctl, rotctl, rigctld, and rotctld utilities.
  * rigctld/rotctld continue working after serial or TCP device
    disappears.
  * Updates and fixes to FT-817, K3, IC-7300, AOR 3030, TM-D710,
    OMNI VII, TH-D72, Flrig, TS-590, piHPSDR, TS-2000, and netrigctl.
  * Update utility manual pages (section 1) and remove their reference
    material from the Info manual so it only needs to be update in one
    file.
  * Add new general project manual pages (section 7) and edit the Info
    manual to match.  These should not change much so keeping them in
    sync should not be too much of a burden.  The Info manual may be
    removed at some point in the future.
  * Last planned release of the present API/ABI.  Future releases will
    require recompilation and relinking by client programs using the C
    library interface (programs that only use the network daemons should
    be unaffected).
* Wed Apr  4 2018 mpluskal@suse.com
- Update dependencies
* Sun Apr  1 2018 mardnh@gmx.de
- Update to version 3.2
  * New models, IC-7850/IC-7851 in IC-785x.  Mike, W9MDB
  * Fix ft991_get_mode, Mike, W9MDB
  * New model, FT-891.  Mike, W9MDB
  * New Barrett 2050 backend, Mike, W9MDB
  * New Flrig backend, Mike, W9MDB
  * New model, IC-M710, Mike, W9MDB
  * Build instructions and test script for Python3
  * Rename autogen.sh to bootsrap and don't call configure
  * micro-ham support. Christoph, DL1YCF
  * New rotator, SPID MD-01/02 in ROT2 mode, Norvald Ryeng, LA6YKA
  * New model, Flex 6400/6600, Mike, W9MDB
  * New model, IC-7610, Mike, W9MDB
  * Add support for CM108B PTT, Max Lock
  * New model, Rohde & Schwarz XK2100, Mike, W9MDB
  * Many other bug fixes and enhancements
- Rebase patch hamlib-3.0-perl_install.patch
* Fri Jun  2 2017 mpluskal@suse.com
- Install all license files
* Thu Apr 27 2017 jengelh@inai.de
- Ensure neutrality of description. Trim duplicate inner
  descrpitions.
* Mon Apr 24 2017 mpluskal@suse.com
- Cleanup package
- Split subpackages with libraries
- Enable tcl and perl bindings:
  * add hamlib-3.0-perl_install.patch
- Run internal testsuite
* Sun Apr 16 2017 mardnh@gmx.de
- update to version 3.1 (tagged release)
- minor specfile cleanup
* Fri Apr  7 2017 dl8fcl@darc.de
- update to version 3.1_git20170406
  New model: Icom IC-R6
  Allow RIG_LEVEL_STRENGTH queries over the network link
* Sun Mar  5 2017 dl8fcl@darc.de
- update to version 3.1_git20170227
  Fix a state machine defect with repeated PTT reset calls
  Add Dorji DRA818 modules (VHF and UHF variants)
* Sun Feb 19 2017 dl8fcl@darc.de
- update to version 3.1_git20170219
  Fix some endian issues in the si570/AVR SDR back ends
  Added x108g backend
  Fix FT-891 recognition
  Breakout FT-1000D file for full support
  Fix DIG MODE for FT817-ND
  Add support for AGC Levels
* Sat Jan 28 2017 dl8fcl@darc.de
- update to version 3.1_git20170127
  Added HPSDR backend
  Fix ic785x default addr to 0x8e
  Clears potential garbage data in read buffer prior to command being sent
  Updated PiHPSDR backend defaults
  Use Windows ioctlsocket to avoid buffer overrun
  Add get and set split functions for the TS450S
  Simplify and fix defects in the FT991 back end
  Added HPSDR backend
* Sat Jan  7 2017 dl8fcl@darc.de
- update to version 3.1_git20170107
  Fix ft991_get_mode
  New models: IC-7849/IC-7851, FT-891
* Sun Dec 25 2016 dl8fcl@t-online.de
- update to version 3.1_git20161225
  Fix typos
  Corrected a few bugs and rebased from Ervin's (HA2OS) pull request.
  Added new example to Python demo script (set/get float type level)
  Added Lua binding and demo script
  Adds test for ID 907 for the Flex 6300
  python-binding and lua-binding enabled
* Sat Nov 19 2016 dl8fcl@t-online.de
- update to version 3.1_git20161119
  Move K3 DT0 before mode switch, add version info to electraft rig open,
  WSJT-X VOX rig split now works
* Tue Nov  8 2016 dl8fcl@t-online.de
- update to version 3.1_git20161106
  New Perseus model
  Fixed buffer overflow in rigctl_parse and rotctl_parse
  Changed some modules to LGPL in lieu of GPL
  Change the IC7600 & IC7800 set/get mode to versions that support DATA…
  fix set_vfo behavior of TS2000
  fix NET rigctl
* Mon Sep  5 2016 dl8fcl@t-online.de
- update to version 3.1_git20160904
  xg3: fix buffer overflow
  Fix issue with TS-570S|D open in rig_caps
  Release the serial port used for PTT when possible
* Sat Aug 27 2016 dl8fcl@t-online.de
- update to version 3.1_git20160827
  Fix an issue presenting on the Yaesu FT-450(D)
  Fix issue with TS-570S|D open in rig_caps
  Updated smeter calibration for ic7300
* Sun Jun 12 2016 dl8fcl@t-online.de
- update to version 3.1_git20160611
  implemented set_conf, get_conf and Token fast_set_commands for max
  throughput
  Yaesu Fast Set Commands (High throughput for commands)
  added send_morse and civ_version to ic7100/ic7600
  added get/set_conf for FT1200, FT2000, FT450, FT5000 and FT9000
  Fixed SCAN_STOP for all rigs and implmented it plus SCOPE for ic7300
  Changes for IC-7300 and IC-7200
* Mon May 23 2016 dl8fcl@t-online.de
- update to version 3.1_git20160521
  Do not attempt to query AI state on several Kenwood rigs
  Add some functionality to the tmd710
  Add send_morse to icom rigs
  Do not crash if expected CTCSS tones not sepcified
  Add RIG_PASSBAND_NOCHANGE as possible set_{split_,split_freq_,}mode a…
  Initial support for the IC-7300
* Mon Apr  4 2016 dl8fcl@t-online.de
- update to version 3.1_git20160402
  Added support for Icom IC-2730
  Use rig state rig port retry option rather than from capabilities
  Use a sensible port timeout value for the Kenwood TS-850
  Make sure right band is used when setting frequency on IC-910(H)
  VFO targetable get frequency operation for the Icom IC-910(h)
  Better set frequency semantics for the IC-910(h)
  Do not swap VFO unnecessarily
  Elide unnecessary CAT commands when setting split frequency and mode
  Add {get,set}_splitfrequency_mode for the IC-910(H)
  Implement rig_{set,get}_split_freq_mode() for IC-756 series.
  Initial implementation of rig_{set,get}_split_freq_mode() for FT-857.
  Implement combined split VFO frequency and mode setting.
  Fixed get_vfo for FT-757GX(II)
  Allow the ft757gx to work with WSJT-X
  Add 23cms to IC-910(H) backend
  Improve IPv6 portability and consistency
  Various Yaesu updates
  Add get_freq to FRG-100
  Favor $HOME over '~' in text
  Fix a logic error in band detection during IC-910 set frequency
  Merge branch 'ic910-set-freq' of git://git.code.sf.net/u/bsomervi/hamlib
* Sat Jan 16 2016 dl8fcl@t-online.de
- update to version 3.1_git20160115
  Fix possible frequency overflow on Kenwood and Yaesu
  Install daemon man files to man1
  New Prosistel rotor backend from IZ7CRX
  Fix missing PKTUSB mode setting code for FT-817 & FT-897
* Fri Dec 11 2015 dl8fcl@darc.de
- update to version 3.1_git20151207
  Fix FT-817/857/897 issues and add some missing functionality
  Use correct function to execute set type commands with no response
  Add a new command line option '--no-restore-ai' ('-n') to rigctl
  Allow for poor emulations of Kenwood rigs that have no ID command
  Attempt to restore AI status on exit
  Proper IPv6 and dual stack networking
* Sun Nov 22 2015 dl8fcl@t-online.de
- update to version 3.1_git20151122
  Remove unecessary delays from TS-940S backend
* Mon Nov  9 2015 dl8fcl@darc.de
- update to version 3.1_git20151109
  change command validation for Yaesu set commands
* Sun Sep 20 2015 dl8fcl@darc.de
- update to version 3.1_git20150920
  fix kenwood_set_mode for ts590s and mode CW, RTTY or AM
* Thu Sep  3 2015 dl8fcl@darc.de
- update to version 3.0_git20150903
  Add library paths for tests
* Sat Aug 22 2015 dl8fcl@darc.de
- update to version 3.0_git20150822
  New CNCTRK rotor backend
* Mon Aug 17 2015 dl8fcl@darc.de
- update to version 3.0_git20150815
  Fixes power level reporting for the Omni VII. Backend is
  promoted to STABLE status.
  Fixes S meter reporting for FT857 and FT991.
  Fixes rig split for FT991. Working now for WSJT-X rig split mode.
* Mon Jul 27 2015 dl8fcl@darc.de
- update to version 3.0_git20150727
  Allows the FT-991 to work with Fake Split in WSJT-X
* Fri Jul 17 2015 dl8fcl@darc.de
- update to version 3.0_git20150717
  Fix for Yaesu FT-991
* Fri Jul  3 2015 dl8fcl@darc.de
- update to version 3.0_git20150703
  Omni VII patch for WSJT-X
* Sat May 23 2015 dl8fcl@darc.de
- update to version 3.0_git20150523
  Omni VII set VFO_CURR correctly
* Sun Apr 26 2015 dl8fcl@darc.de
- update to version 3.0_git20150425 - beta version
  with a lot of new features and new rig backends
* Fri Nov  9 2012 dl8fcl@darc.de
- update to version 1.2.15.3
* Fri Feb  3 2012 dl8fcl@darc.de
- update to version 1.2.15
* Sun Jul 31 2011 dl8fcl@darc.de
- update to version 1.2.14
* Sun May 29 2011 dl8fcl@darc.de
- update to version 1.2.13.1
* Sun Mar 13 2011 dl8fcl@darc.de
- update to version 1.2.13
* Mon Sep  6 2010 dl8fcl@darc.de
- update to version 1.2.12
* Mon Jun  7 2010 dl8fcl@darc.de
- update to version 1.2.11
* Mon Nov  2 2009 dl8fcl@darc.de
- update to version 1.2.10
* Sun Mar  1 2009 dl8fcl@darc.de
- update to version 1.2.9
* Mon Nov  3 2008 dl8fcl@darc.de
- update to version 1.2.8
- disabled src_misc_c_strcmp.diff
* Sun Jul 22 2007 dl9pf@gmx.de
- version 1.2.6.2
* Tue Feb 20 2007 dl9pf@gmx.de
- import into buildservice
- version 1.2.6
  * Tue Jun 20 2006 Tim Fischer
- rewrite spec file for SUSE 10.1
  * Tue Sep 26 2004 Stephane Fillod
- New backends: skanti, racal, wj, tuner
- New command 'rigswr'
  * Tue Jan 20 2004 Tomi Manninen
- Fix for 1.1.5pre2
- Better use of rpm macros
- Disable all bindings
  * Tue Oct 08 2003 Joop Stakenborg
- Fix 'make rpm' again by disabling c++ bindings.
- rotclass.h and rigclass.h go into the devel package for now (FIXME)
  * Wed Jan 15 2003 Joop Stakenborg
- Fix the spec file for 1.1.4CVS
- 'make rpm' should work now
  * Thu Jun 17 2002 Stephane Fillod
- Added rotator support
- Added RPC daemon, hamlib.m4
  * Mon Jul 18 2001 Stephane Fillod
- Made initial "working" SPEC file
